@@ -7,14 +7,15 @@ from rfdoc.rfdocapp import views
 admin.autodiscover()
 
 urlpatterns = patterns('',
-    url(r'^admin/', include(admin.site.urls)),
-    (r'^upload/?$', views.upload),
-    (r'^search/?$', views.search),
-    (r'^lib/(.*)', views.library),
-    (r'^$', views.index)
+    url(r'^admin/', include(admin.site.urls), name='admin'),
+    url(r'^upload/?$', views.upload, name='upload'),
+    url(r'^search/?$', views.search, name='search'),
+    url(r'^lib/(.*)$', views.library, name='library'),
+    url(r'^lib/(.*)/(.*)$', views.library, name='keyword'),
+    url(r'^$', views.index, name='root')
 )
 
-# Force Django's server to serve static assets, if this is not the production
+# Force Django to serve static assets, if this is not the production
 if settings.PRODUCTION is False:
     urlpatterns += patterns('', (
         r'^static/(?P<path>.*)$', 'django.views.static.serve', {
